Module for handling dynamic updates to the music library.
This module is only available when the dynamic_updates feature is enabled.
The init_music_library_watcher
Structs
Constants
Functions
- init_
music_ library_ watcher - uses the notify crate to update the internal music library (database) when changes to configured music library directories are detected.