start_daemon

Function start_daemon 

pub async fn start_daemon(
    settings: Settings,
    db_dir: PathBuf,
    log_file_path: Option<PathBuf>,
    state_file_path: Option<PathBuf>,
) -> Result<()>
Run the daemon

also initializes the logger, database, and other necessary components.

Arguments

  • settings - The settings to use.
  • db_dir - The directory where the database is stored. If the directory does not exist, it will be created.
  • log_file_path - The path to the file where logs will be written.
  • state_file_path - The path to the file where the queue state restored from / saved to.

Errors

If the daemon cannot be started, an error is returned.

Panics

Panics if the peer address of the underlying TCP transport cannot be determined.