pub struct QueueState {
pub repeat_mode: RepeatMode,
pub muted: bool,
pub volume: f32,
pub queue: Box<[SongBrief]>,
pub queue_position: Option<usize>,
pub seek_position: Option<Duration>,
}Fields
repeat_mode: RepeatModemuted: boolvolume: f32queue: Box<[SongBrief]>queue_position: Option<usize>seek_position: Option<Duration>Implementations
Sourceimpl QueueState
impl QueueState
Sourcepub async fn retrieve(audio_kernel: &AudioKernelSender) -> Result<Self>
pub async fn retrieve(audio_kernel: &AudioKernelSender) -> Result<Self>
Get the state from the audio kernel
Errors
Returns an error if the status cannot be retrieved from the audio kernel
Sourcepub fn restore_to(&self, audio_kernel: &AudioKernelSender)
pub fn restore_to(&self, audio_kernel: &AudioKernelSender)
Restore the state into the audio kernel
Sourcepub fn save_to_file(&self, path: &Path) -> Result<()>
pub fn save_to_file(&self, path: &Path) -> Result<()>
Save the state to a file This will overwrite the file if it exists
Errors
Returns an error if the file cannot be created or written to or if the state cannot be serialized.
Sourcepub fn load_from_file(path: &Path) -> Result<Self>
pub fn load_from_file(path: &Path) -> Result<Self>
Load the state from a file
Errors
Returns an error if the file cannot be opened or read or if the state cannot be deserialized.