Module services

Modules

library
radio

Functions

get_songs_from_things
Get the songs associated with every thing in the list. This function will go through the list of things and get the songs associated with each thing. It will then remove duplicates from the list of songs.