pub async fn full<C: Connection>(db: &Surreal<C>) -> Result<LibraryFull, Error>Expand description
Get the full library.
Errors
This function will return an error if there is an error reading from the database.
pub async fn full<C: Connection>(db: &Surreal<C>) -> Result<LibraryFull, Error>Get the full library.
This function will return an error if there is an error reading from the database.