pub struct InterruptReceiver { /* private fields */ }Expand description
Used to handle the termination of the application.
A struct that handles listening for interrupt signals, and/or tracking whether an interrupt signal has been received.
Essentially, the receiving side of the broadcast channel.
Implementations
Sourceimpl InterruptReceiver
impl InterruptReceiver
pub fn new(interrupt_rx: Receiver<Interrupted>) -> Self
Sourcepub fn dummy() -> Self
pub fn dummy() -> Self
Create a dummy receiver that doesn’t receive any signals
Attempting to wait on this receiver will wait indefinitely.
Sourcepub async fn wait(&mut self) -> Result<Interrupted, RecvError>
pub async fn wait(&mut self) -> Result<Interrupted, RecvError>
Wait for an interrupt signal to be received.
Errors
Fails if the interrupt signal cannot be received (e.g. the sender has been dropped)
Sourcepub fn resubscribe(&self) -> Self
pub fn resubscribe(&self) -> Self
Re-subscribe to the broadcast channel.
Gives you a new receiver that can be used to receive interrupt signals.
Sourcepub fn is_stopped(&self) -> bool
pub fn is_stopped(&self) -> bool
Check if an interrupt signal has been received previously.