Terminator

Struct Terminator 

pub struct Terminator { /* private fields */ }
Used to handle the termination of the application.

A struct that handles sending interrupt signals to the application.

Essentially, the sending side of the broadcast channel.

Implementations

Source

impl Terminator

pub const fn new(interrupt_tx: Sender<Interrupted>) -> Self

pub fn terminate(&self, interrupted: Interrupted) -> Result<()>

Send an interrupt signal to the application.

Errors

Fails if the interrupt signal cannot be sent (e.g. the receiver has been dropped)