Modules
- controller
- dynamic_
updates - Module for handling dynamic updates to the music library.
- services
- termination
Constants
- MAX_
CONCURRENT_ REQUESTS - The maximum number of concurrent requests.
Functions
- init_
test_ client_ server - Initialize a test client, sends and receives messages over a channel / pipe. This is useful for testing the server without needing to start it.
- start_
daemon - Run the daemon