Crate mecomp_daemon

Modules

controller
dynamic_updates
Module for handling dynamic updates to the music library.
services

Functions

init_test_client_server
Initialize a test client, sends and receives messages over a channel / pipe. This is useful for testing the server without needing to start it.
start_daemon
Run the daemon