pub struct Settings {
pub daemon: DaemonSettings,
pub reclustering: ReclusterSettings,
}Fields
daemon: DaemonSettingsGeneral Daemon Settings
reclustering: ReclusterSettingsParameters for the reclustering algorithm.
Implementations
sourceimpl Settings
impl Settings
sourcepub fn init(
config: PathBuf,
port: Option<u16>,
log_level: Option<LevelFilter>,
) -> Result<Self, ConfigError>
pub fn init( config: PathBuf, port: Option<u16>, log_level: Option<LevelFilter>, ) -> Result<Self, ConfigError>
Load settings from the config file, environment variables, and CLI arguments.
The config file is located at the path specified by the --config flag.
The environment variables are prefixed with MECOMP_.
Arguments
flags- The parsed CLI arguments.
Errors
This function will return an error if the config file is not found or if the config file is invalid.