pub async fn init_test_client_server(
db: Arc<Surreal<Db>>,
settings: Arc<Settings>,
audio_kernel: Arc<AudioKernelSender>,
) -> Result<MusicPlayerClient>Expand description
Initialize a test client, sends and receives messages over a channel / pipe. This is useful for testing the server without needing to start it.
Errors
Errors if the event publisher cannot be created.