mecomp_daemon

Module services

source

Modules

Functions

  • Get the songs associated with every thing in the list. This function will go through the list of things and get the songs associated with each thing. It will then remove duplicates from the list of songs.