pub fn create_termination() -> (Terminator, InterruptReceiver)Expand description
create a broadcast channel for retrieving the application kill signal
Panics
This function will panic if the tokio runtime cannot be created.
pub fn create_termination() -> (Terminator, InterruptReceiver)create a broadcast channel for retrieving the application kill signal
This function will panic if the tokio runtime cannot be created.